@@ -4,12 +4,12 @@ test_that("calc_nleach works", {
     calc_nleach(
       B_SOILTYPE_AGR = c('dekzand','zeeklei','rivierklei','loess'),
       B_LU_BRP = c(265, 2014, 259, 259), # grasland, bouwland, mais, mais
-      B_GWL_CLASS = c('GtIV','GtV','GtIII','GtII'),
+      B_GWL_CLASS = c('IV','V','III','II'),
       D_NLV = c(5, 30, 100, 150),
       B_AER_CBS = c('Rivierengebied', 'Rivierengebied', 'Centraal Veehouderijgebied', 'Centraal Veehouderijgebied'),
       leaching_to = "gw"
     ),
-    expected = c(0.41, 0.39, 5.99, 15.64),
+    expected = c(0.41, 0.39, 5.77, 15.64),
     tolerance = 0.001
   )
   
@@ -32,12 +32,12 @@ test_that("calc_nleach works", {
     calc_nleach(
       B_SOILTYPE_AGR = c('dekzand','zeeklei','rivierklei','loess'),
       B_LU_BRP = c(265, 2014, 259, 259), # grasland, bouwland, mais, mais
-      B_GWL_CLASS = c('GtIV','GtV','GtIII','GtII'),
+      B_GWL_CLASS = c('IV','V','III','II'),
       D_NLV = c(5, 30, 100, 150),
       B_AER_CBS = c('Rivierengebied', 'Rivierengebied', 'Centraal Veehouderijgebied', 'Centraal Veehouderijgebied'),
       leaching_to = "ow"
     ),
-    expected = c(0.095, 0.270, 4.66, 19.9),
+    expected = c(0.095, 0.270, 4.49, 19.90),
     tolerance = 0.001
   )
 })
@@ -63,4 +63,4 @@ test_that("ind_nretention ow works", {
     expected = c( 9.749461e-01, 4.992744e-01, 3.997841e-02, 1.890118e-03, 8.650998e-05, 0, 0, 0),
     tolerance = 0.001
   )
-})
\ No newline at end of file
+})
